@@ -83,7 +83,6 @@ use constant {
 };
 use 5.010;
 
-use Data::Dumper::Simple;
 use Switch;          # Yes, a touch of new Perl. Switch is so much nicer
                      # a ton of if-else's
 use Math::Trig qw(:pi);    # Yes, yummy PI
@@ -93,12 +92,11 @@ use Sys::Mmap;             # Absolutely necessary to map the screen to a string.
 use Imager;                # This is used for TrueType font printing, and where
                            # 'Pure Perl' goes up in smoke.
 
-
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION   = 4.19;
+    our $VERSION   = 4.21;
     our @ISA       = qw(Exporter);
     our @EXPORT    = qw();
     our @EXPORT_OK = qw();
@@ -277,7 +275,7 @@ sub new {
 
         bless($self, $class);
 
-        attribute_reset($self);
+        $self->attribute_reset();
     } ## end else [ if (open($self->{'FB'}...))]
     return $self;
 } ## end sub new
@@ -298,13 +296,11 @@ $fb->screen_close();
 sub screen_close {
     my $self = shift;
     if (!defined($self->{'ERROR'})) {    # Only do it if not in emulation mode
-        munmap($self->{'SCREEN2'}) if (defined($self->{'SCREEN2'}));
         munmap($self->{'SCREEN'}) if (defined($self->{'SCREEN'}));
         close($self->{'FB'}) if (defined($self->{'FB'}));
         delete($self->{'FB'});           # We leave no remnants MUHWAHAHAHAHA!!!
     }
     delete($self->{'SCREEN'});           # MUHWAHAHAHA!!
-    delete($self->{'SCREEN2'});          # MUHWAHAHAHA!!
 } ## end sub screen_close
 ###############################################################
 
@@ -544,6 +540,9 @@ sub plot {
 
         # Only plot if the pixel is within the clipping region
         unless (($x > $self->{'XX_CLIP'}) || ($y > $self->{'YY_CLIP'}) || ($x < $self->{'X_CLIP'}) || ($y < $self->{'Y_CLIP'})) {
+            # SV* smem_start, SV* smem_length, SV* bits_per_pixel, SV* bytes, SV* line_length,
+            # SV* xoffset, SV* yoffset, SV* width, SV* height, SV* draw_mode, SV* x, SV* y
+
 
             # The 'history' is a 'draw_arc' optimization and beautifier for xor mode.  It only draws pixels not in
             # the history buffer.
@@ -2384,7 +2383,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 4.19 (July 16, 2015)
+Version 4.21 (July 16, 2015)
 
 =head1 THANKS
 
@@ -2395,3 +2394,4 @@ Troy Beisigl
 Markus Maier
 
 =cut
+
